/*
 * Access a server offering a compound interface.
 *
 * Copyright (C) 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/re/env.h>

#include <stdio.h>

#include "calc_client.h"
#include "counter_client.h"

int main(void)
{
  l4_cap_idx_t server = l4re_env_get_cap("server");

  /* Calculator encapsulation. */

  client_Calc calc_obj(server);

  /* Counter encapsulation. */

  client_Counter counter_obj(server);

  /* Call the calculator. */

  int result;

  /* Invoke the operation via the interface. */

  calc_obj.add(789, 123, &result);
  printf("add 789, 123 -> %d\n", result);

  /* Call the counter. */

  /* Invoke the operation via the interface. */

  counter_obj.increment(&result);
  printf("increment -> %d\n", result);

  return 0;
}
